
#Region "Header Information"
' -----------------------------------------------------------------------------
' Project: [ARDISOptiSave]
' Form/Class  : [clsFormsManagement]
' 
' -----------------------------------------------------------------------------
' <summary>
' this class is used to keep track of all open form within the MDI parent
' and determine what functionality is available to the currently displayed
' form.
'   
' 
' </summary>
' <remarks>
'
' </remarks>
' Revision History
' Date       Name            Description
' ========   ============    ===========
' 02/27/08   Patrick Roy     Created initial layout and routines 
'
'
' </history>
' Date       Name            Description
' ========   ============    ===========
' 02/28/08   Patrick Roy     Modified code 
'
'
' -----------------------------------------------------------------------------
#End Region

Imports System.IO
Imports System.Math
Imports System.Security
Imports System.Security.Cryptography
Imports System.Text
Imports System.Collections

Public Class clsFormsManagement
     Private CLASS_NAME As String = MyBase.GetType().Name

     '**************************************************************
#Region "Enums"
     Public Enum FormDataType
          FormIndexVal = 10
          FormName = 20
          RibbonVal = 30
          PrintYN = 40
          ExportYN = 50
          OpenFileYN = 60
          SaveYN = 70
          SaveAllYN = 80
          EditYN = 90
          oCut = 100
          oCopy = 110
          oPaste = 120
          HelpYN = 130
          IsActiveYN = 140
          AllowMultiWinYN = 150
     End Enum
#End Region 'Enums
     '**************************************************************
#Region "Constants"
     Private Const sFormManagementFileName As String = "FormsManager"
     Private Const sFrmMgtExt As String = ".txt"
     '^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
     Private Const eRETURN_NOTHING As String = "NOTHING"
     Private Const dRETURN_ERROR As String = "ERROR"
     '^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
#End Region  'Constants
     '**************************************************************
#Region "Public/Private variables"
     Private m_CurrentFormName As String
     Private m_RibbonUsed As Boolean
     Private m_NumOfFormsActive As Integer
     Private m_CurrentFormIndex As Integer
     Private m_ApplicationDirectory As String
     Private m_CurrentDate As String
     Private _dt As DataTable
     Private _ds As DataSet
     Private _dv As DataView
     Private _dr As DataRow
#End Region 'Public/Private variables
     '**************************************************************

#Region "Properties"
     '--------------------------------------------
     Public Property CurrentFormName() As String
          Get
               Return m_CurrentFormName
          End Get
          Set(ByVal value As String)
               m_CurrentFormName = value
          End Set
     End Property
     '---------------------------------------------
     Public Property ApplicationDirectory() As String
          Get
               Return m_ApplicationDirectory
          End Get
          Set(ByVal value As String)
               m_ApplicationDirectory = value
          End Set
     End Property
     '---------------------------------------------
     Public Property CurrentDate() As String
          Get
               Return m_CurrentDate
          End Get
          Set(ByVal value As String)
               m_CurrentDate = value
          End Set
     End Property
     '---------------------------------------------
     Public Property NumOfFormsActive() As Integer
          Get
               Return m_NumOfFormsActive
          End Get
          Set(ByVal value As Integer)
               m_NumOfFormsActive = value
          End Set
     End Property
     '---------------------------------------------
#End Region 'Properties
     '**************************************************************
#Region "Functions and subroutines"
     Public Function ClearFormFromList() As Boolean

     End Function
     Private Sub Initiate()
          '-----------------------------------
          Dim SUB_NAME As String = "Initiate"
          '-----------------------------------
          Try
               _ds = New DataSet
               _dt = New DataTable
               _dv = New DataView
               '...............................
               _dt.Columns.Add("FormIndex")
               _dt.Columns.Add("FormName")
               _dt.Columns.Add("AllowMultiWinYN")
               _dt.Columns.Add("IsActiveYN")
               _dt.Columns.Add("RibbonVal")
               _dt.Columns.Add("PrintYN")
               _dt.Columns.Add("ExportYN")
               _dt.Columns.Add("OpenFileYN")
               _dt.Columns.Add("SaveYN")
               _dt.Columns.Add("SaveAllYN")
               _dt.Columns.Add("EditYN")
               _dt.Columns.Add("Cut")
               _dt.Columns.Add("Copy")
               _dt.Columns.Add("Paste")
               _dt.Columns.Add("HelpYN")
               '...............................
               _ds.Tables.Add(_dt)
               _dv.Table = _ds.Tables(0)
          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, SUB_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oSub)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, SUB_NAME)
               'End If
          Finally
               SUB_NAME = Nothing
          End Try

     End Sub
     '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Public Function GetFormValues(ByVal sFormName As String) As String
          '--------------------------------------
          Dim FUNCTION_NAME As String = "GetFormValues"
          '--------------------------------------
          Try


               Return Nothing
          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, FUNCTION_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oFunction)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, FUNCTION_NAME)
               'End If
               Return clsFormsManagement.dRETURN_ERROR
          Finally
               FUNCTION_NAME = Nothing
          End Try
     End Function
     '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Public Function SetFormName(ByVal sFormName As String) As Boolean
          '--------------------------------------
          Dim FUNCTION_NAME As String = "SetFormName"
          '--------------------------------------
          Try



          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, FUNCTION_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oFunction)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, FUNCTION_NAME)
               'End If
          Finally
               FUNCTION_NAME = Nothing
          End Try
     End Function
     '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Private Function SetFormIndexVal() As Integer
          '--------------------------------------
          Dim FUNCTION_NAME As String = "SetFormIndexVal"
          '--------------------------------------
          Try



          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, FUNCTION_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oFunction)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, FUNCTION_NAME)
               'End If
          Finally
               FUNCTION_NAME = Nothing
          End Try
     End Function
     '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Public Function SendFormMgtDataToMsgFile() As Boolean
          '--------------------------------------
          Dim FUNCTION_NAME As String = "SendFormMgtDataToFile"
          '--------------------------------------
          Try



          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, FUNCTION_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oFunction)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, FUNCTION_NAME)
               'End If
          Finally
               FUNCTION_NAME = Nothing
          End Try
     End Function
     '++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
     Private Function GetFormDataTypeStr(ByVal iFrmStrType As FormDataType) As String
          '--------------------------------------
          Dim FUNCTION_NAME As String = "GetFormDataTypeStr"
          '--------------------------------------
          Dim strValue As String = Nothing
          Try
               '-------------------------------------
               Select Case iFrmStrType
                    Case FormDataType.FormIndexVal
                         strValue = "FormIndex"
                    Case FormDataType.FormName
                         strValue = "FormName"
                    Case FormDataType.IsActiveYN
                         strValue = "IsActiveYN"
                    Case FormDataType.EditYN
                         strValue = "EditYN"
                    Case FormDataType.ExportYN
                         strValue = "ExportYN"
                    Case FormDataType.HelpYN
                         strValue = "HelpYN"
                    Case FormDataType.oCopy
                         strValue = "Copy"
                    Case FormDataType.oCut
                         strValue = "Cut"
                    Case FormDataType.oPaste
                         strValue = "Paste"
                    Case FormDataType.PrintYN
                         strValue = "PrintYN"
                    Case FormDataType.OpenFileYN
                         strValue = "OpenFileYN"
                    Case FormDataType.RibbonVal
                         strValue = "RibbonVal"
                    Case FormDataType.SaveAllYN
                         strValue = "SaveAllYN"
                    Case FormDataType.SaveYN
                         strValue = "EditYN"
                    Case FormDataType.AllowMultiWinYN
                         strValue = "AllowMultiWinYN"
                         '-------------------------------
                    Case Else
                         strValue = clsFormsManagement.eRETURN_NOTHING
               End Select
               '..................................
               Return strValue
          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, FUNCTION_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oFunction)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, FUNCTION_NAME)
               'End If
               Return clsFormsManagement.dRETURN_ERROR
          Finally
               FUNCTION_NAME = Nothing
               strValue = Nothing
          End Try
     End Function
     Private Sub SetCurrentDate()
          '-----------------------------------
          Dim SUB_NAME As String = "SetCurrentDate"
          '-----------------------------------
          Try
               CurrentDate = Format(Now, "mm-d-yy")


          Catch ex As Exception
               '<<<<<<<<<<<<<<<<< error msg with debug option msg >>>>>>>>>>>>>>>>
               'If g_oSetupData.DEBUG_ON_OFF Then
               '     gbol_Answerval = g_MsgFile.StoreMessageToFile(CLASS_NAME, SUB_NAME, "Error Message Encountered", ex.Message, clsMessageFile.MessageType.ErrorMsg, clsMessageFile.Class_FormType.oSub)
               'Else
               '     g_oError.WriteToLog(ex.Message, clsError.EV_Error_Type.oError, "NOT KNOWN", CLASS_NAME, SUB_NAME)
               'End If
          Finally
               SUB_NAME = Nothing
          End Try

     End Sub
#End Region 'Functions and subroutines
     '**************************************************************
#Region "Class routines"
     Public Sub New()
          '_ds = New DataSet
          '_dt = New DataTable
          '_dv = New DataView
          ''...............................
          '_dt.Columns.Add("FormIndex")
          '_dt.Columns.Add("FormName")
          '_dt.Columns.Add("AllowMultiWinYN")
          '_dt.Columns.Add("IsActiveYN")
          '_dt.Columns.Add("RibbonYN")
          '_dt.Columns.Add("PrintYN")
          '_dt.Columns.Add("ExportYN")
          '_dt.Columns.Add("OpenFileYN")
          '_dt.Columns.Add("SaveYN")
          '_dt.Columns.Add("SaveAllYN")
          '_dt.Columns.Add("EditYN")
          '_dt.Columns.Add("Cut")
          '_dt.Columns.Add("Copy")
          '_dt.Columns.Add("Paste")
          '_dt.Columns.Add("HelpYN")
          ''...............................
          '_ds.Tables.Add(_dt)
          '_dv.Table = _ds.Tables(0)
          '....................
          Initiate()
          '.....................
          ApplicationDirectory = My.Application.Info.DirectoryPath & "\"
          SetCurrentDate()
     End Sub
     Protected Overrides Sub Finalize()
          MyBase.Finalize()
          _ds = Nothing
          _dt = Nothing
          _dv = Nothing
     End Sub
#End Region 'Class routines


End Class
